@@ -1,41 +1,48 @@
 use std::future::Future;
 use std::pin::Pin;
-use std::time::Duration;
 
-use async_io::Timer;
 use pin_project_lite::pin_project;
 
 use core::task::{Context, Poll};
 
 pin_project! {
     /// A future that delays execution by the specified time.
+    #[must_use = "futures do nothing unless polled or .awaited"]
     #[derive(Debug)]
-    pub struct Delay<F> {
+    pub struct Delay<F, D> {
         #[pin]
         future: F,
         #[pin]
-        delay: Timer,
+        deadline: D,
+        completed: bool,
     }
 }
 
-impl<F> Delay<F> {
-    pub(crate) fn new(future: F, dur: Duration) -> Delay<F> {
-        let delay = Timer::after(dur);
-
-        Delay { future, delay }
+impl<F, D> Delay<F, D> {
+    pub(crate) fn new(future: F, deadline: D) -> Self {
+        Self {
+            future,
+            deadline,
+            completed: false,
+        }
     }
 }
 
-impl<F: Future> Future for Delay<F> {
+impl<F: Future, D: Future> Future for Delay<F, D> {
     type Output = F::Output;
 
     fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
+        assert!(!self.completed, "Future polled after completing");
+
         let this = self.project();
 
-        match this.delay.poll(cx) {
+        match this.deadline.poll(cx) {
             Poll::Pending => Poll::Pending,
             Poll::Ready(_) => match this.future.poll(cx) {
-                Poll::Ready(v) => Poll::Ready(v),
+                Poll::Ready(v) => {
+                    *this.completed = true;
+                    Poll::Ready(v)
+                }
                 Poll::Pending => Poll::Pending,
             },
         }
