@@ -1,40 +1,25 @@
 use core::future::Future;
-use std::time::{Duration, Instant};
 
-use super::{Delay, DelayUntil, Timeout, TimeoutAt};
+use super::{Delay, IntoFuture, Timeout};
 
 /// Extend `Future` with time-based operations.
 pub trait FutureExt: Future {
     /// Await a future or times out after a duration of time.     
-    fn timeout(self, dur: Duration) -> Timeout<Self>
+    fn timeout<D>(self, deadline: D) -> Timeout<Self, D::IntoFuture>
     where
         Self: Sized,
+        D: IntoFuture,
     {
-        Timeout::new(self, dur)
-    }
-
-    /// Await a future or times out at the given deadline.
-    fn timeout_at(self, deadline: Instant) -> TimeoutAt<Self>
-    where
-        Self: Sized,
-    {
-        TimeoutAt::new(self, deadline)
+        Timeout::new(self, deadline.into_future())
     }
 
     /// Returns a future that delays execution for a specified time.
-    fn delay(self, dur: Duration) -> Delay<Self>
+    fn delay<D>(self, deadline: D) -> Delay<Self, D::IntoFuture>
     where
         Self: Sized,
+        D: IntoFuture,
     {
-        Delay::new(self, dur)
-    }
-
-    /// Returns a future that delays execution for a specified time.
-    fn delay_until(self, deadline: Instant) -> DelayUntil<Self>
-    where
-        Self: Sized,
-    {
-        DelayUntil::new(self, deadline)
+        Delay::new(self, deadline.into_future())
     }
 }
 
